@@ -5,5 +5,7 @@ from motorengine.query.base import QueryOperator
 
 
 class GreaterThanOrEqualQueryOperator(QueryOperator):
-    def to_query(self):
-        return {"$gte": self.value}
+    def to_query(self, field_name, value):
+        return {
+            field_name: {"$gte": value}
+        }
